# frozen_string_literal: true

require "gir_ffi_test_helper"

describe GirFFI::Builders::BaseArgumentBuilder do
end
